import { TextDocument } from 'vscode-languageserver-textdocument';
export type { LanguageServiceHost } from 'typescript';
import type { LanguageServiceHost } from 'typescript';
export declare type LanguageService = ReturnType<typeof createLanguageService>;
export { getSemanticTokenLegend } from './services/semanticTokens';
export declare function createLanguageService(_host: LanguageServiceHost, ts: typeof import('typescript/lib/tsserverlibrary')): {
    findDefinition: (uri: string, position: import("vscode-languageserver-protocol").Position) => import("vscode-languageserver-protocol").LocationLink[];
    findTypeDefinition: (uri: string, position: import("vscode-languageserver-protocol").Position) => import("vscode-languageserver-protocol").LocationLink[];
    findReferences: (uri: string, position: import("vscode-languageserver-protocol").Position) => import("vscode-languageserver-protocol").Location[];
    prepareRename: (uri: string, position: import("vscode-languageserver-protocol").Position) => import("vscode-languageserver-protocol").Range | import("vscode-jsonrpc").ResponseError<void> | undefined;
    doRename: (uri: string, position: import("vscode-languageserver-protocol").Position, newName: string) => import("vscode-languageserver-protocol").WorkspaceEdit | undefined;
    getEditsForFileRename: (oldUri: string, newUri: string) => import("vscode-languageserver-protocol").WorkspaceEdit | undefined;
    getCodeActions: (uri: string, range: import("vscode-languageserver-protocol").Range, context: import("vscode-languageserver-protocol").CodeActionContext) => import("vscode-languageserver-protocol").CodeAction[] | undefined;
    doCodeActionResolve: (codeAction: import("vscode-languageserver-protocol").CodeAction) => import("vscode-languageserver-protocol").CodeAction;
    findDocumentHighlights: (uri: string, position: import("vscode-languageserver-protocol").Position) => import("vscode-languageserver-protocol").DocumentHighlight[];
    findDocumentSymbols: (uri: string) => import("vscode-languageserver-protocol").DocumentSymbol[];
    findWorkspaceSymbols: (uri: string) => import("vscode-languageserver-protocol").SymbolInformation[];
    doComplete: (uri: string, position: import("vscode-languageserver-protocol").Position, options?: import("typescript").GetCompletionsAtPositionOptions | undefined) => import("vscode-languageserver-protocol").CompletionItem[];
    doCompletionResolve: (item: import("vscode-languageserver-protocol").CompletionItem, newOffset?: number | undefined) => import("vscode-languageserver-protocol").CompletionItem;
    doHover: (uri: string, position: import("vscode-languageserver-protocol").Position, documentOnly?: boolean) => import("vscode-languageserver-protocol").Hover | undefined;
    doFormatting: (uri: string, options: import("vscode-languageserver-protocol").FormattingOptions, range?: import("vscode-languageserver-protocol").Range | undefined) => import("vscode-languageserver-protocol").TextEdit[];
    getSignatureHelp: (uri: string, position: import("vscode-languageserver-protocol").Position) => import("vscode-languageserver-protocol").SignatureHelp | undefined;
    getSelectionRange: (uri: string, position: import("vscode-languageserver-protocol").Position) => import("vscode-languageserver-protocol").SelectionRange | undefined;
    doValidation: (uri: string, options: {
        semantic?: boolean | undefined;
        syntactic?: boolean | undefined;
        suggestion?: boolean | undefined;
        declaration?: boolean | undefined;
    }, cancellationToken?: import("typescript").CancellationToken | undefined) => import("vscode-languageserver-protocol").Diagnostic[];
    getFoldingRanges: (uri: string) => import("vscode-languageserver-protocol").FoldingRange[];
    getDocumentSemanticTokens: (uri: string, range: import("vscode-languageserver-protocol").Range, cancle?: import("vscode-jsonrpc").CancellationToken | undefined) => [number, number, number, number, number][] | undefined;
    callHierarchy: {
        doPrepare: (uri: string, position: import("vscode-languageserver-protocol").Position) => import("vscode-languageserver-protocol").CallHierarchyItem[];
        getIncomingCalls: (item: import("vscode-languageserver-protocol").CallHierarchyItem) => import("vscode-languageserver-protocol").CallHierarchyIncomingCall[];
        getOutgoingCalls: (item: import("vscode-languageserver-protocol").CallHierarchyItem) => import("vscode-languageserver-protocol").CallHierarchyOutgoingCall[];
    };
    dispose: () => void;
    __internal__: {
        raw: import("typescript/lib/tsserverlibrary").LanguageService;
        host: {
            getImportSuggestionsCache: () => any;
            getCompilationSettings(): import("typescript").CompilerOptions;
            getNewLine?(): string;
            getProjectVersion?(): string;
            getScriptFileNames(): string[];
            getScriptKind?(fileName: string): import("typescript").ScriptKind;
            getScriptVersion(fileName: string): string;
            getScriptSnapshot(fileName: string): import("typescript").IScriptSnapshot | undefined;
            getProjectReferences?(): readonly import("typescript").ProjectReference[] | undefined;
            getLocalizedDiagnosticMessages?(): any;
            getCancellationToken?(): import("typescript").HostCancellationToken;
            getCurrentDirectory(): string;
            getDefaultLibFileName(options: import("typescript").CompilerOptions): string;
            log?(s: string): void;
            trace?(s: string): void;
            error?(s: string): void;
            useCaseSensitiveFileNames?(): boolean;
            readDirectory?(path: string, extensions?: readonly string[] | undefined, exclude?: readonly string[] | undefined, include?: readonly string[] | undefined, depth?: number | undefined): string[];
            readFile?(path: string, encoding?: string | undefined): string | undefined;
            realpath?(path: string): string;
            fileExists?(path: string): boolean;
            getTypeRootsVersion?(): number;
            resolveModuleNames?(moduleNames: string[], containingFile: string, reusedNames: string[] | undefined, redirectedReference: import("typescript").ResolvedProjectReference | undefined, options: import("typescript").CompilerOptions): (import("typescript").ResolvedModule | undefined)[];
            getResolvedModuleWithFailedLookupLocationsFromCache?(modulename: string, containingFile: string): import("typescript").ResolvedModuleWithFailedLookupLocations | undefined;
            resolveTypeReferenceDirectives?(typeDirectiveNames: string[], containingFile: string, redirectedReference: import("typescript").ResolvedProjectReference | undefined, options: import("typescript").CompilerOptions): (import("typescript").ResolvedTypeReferenceDirective | undefined)[];
            getDirectories?(directoryName: string): string[];
            getCustomTransformers?(): import("typescript").CustomTransformers | undefined;
            isKnownTypesPackageName?(name: string): boolean;
            installPackage?(options: import("typescript").InstallPackageOptions): Promise<import("typescript").ApplyCodeActionCommandResult>;
            writeFile?(fileName: string, content: string): void;
            directoryExists?(directoryName: string): boolean;
        };
        getTextDocument: (uri: string) => TextDocument | undefined;
        getTextDocument2: (uri: string) => TextDocument | undefined;
    };
};
